# HolyTFTP

HolyTFTP is a TFTP server with GUI, written in python3.
It's a part of the HolySoftware project, which aims to provide os-independent softwares.



## Installation

```
pip install holytftp
```

